@@ -1,15 +1,14 @@
 package MySQL::Easy;
 
-# $Id: Easy.pm,v 1.12 2002/02/25 18:58:45 jettero Exp $
+# $Id: Easy.pm,v 1.8 2002/01/17 17:55:22 jettero Exp $
 # vi:fdm=marker fdl=0:
 
 use strict;
 use warnings;
-use Carp;
 
 use DBI;
 
-our $VERSION = "0.99.7b";
+our $VERSION = "0.99b";
 
 return 1;
 
@@ -30,12 +29,7 @@ sub new {
 sub do {
     my $this = shift; return unless @_;
 
-    my $e = $SIG{__WARN__}; $SIG{__WARN__} = sub {};
-    my $r = $this->ready(shift)->execute(@_) or croak $this->errstr;
-
-    $SIG{__WARN__} = $e;
-
-    return $r;
+    $this->ready(shift)->execute(@_);
 }
 # }}}
 # lock {{{
@@ -83,19 +77,6 @@ sub errstr {
     return $this->handle->errstr;
 }
 # }}}
-# last_insert_id {{{
-sub last_insert_id {
-    my $this = shift;
-
-    return $this->firstcol("select last_insert_id()")->[0];
-}
-# }}}
-
-sub DESTROY {
-    my $this = shift;
-
-    $this->{dbh}->disconnect if $this->{dbh};
-}
 
 # handle {{{
 sub handle {
@@ -109,7 +90,7 @@ sub handle {
         $this->{trace} =           0 unless $this->{trace};
 
         $this->{dbh} = DBI->connect("DBI:mysql:$this->{dbase}:$this->{host}", $this->{user}, $this->{pass});
-        $this->{dbh}->trace($this->{trace}) if $this->{dbh};
+        $this->{dbh}->trace($this->{trace});
     }
 
     return $this->{dbh};
@@ -123,10 +104,9 @@ sub unp {
 
     open PASS, "$ENV{HOME}/.my.cnf" or die "$!";
 
-    my $l;
-    while($l = <PASS>) {
-        $user = $1 if $l =~ m/user\s*=\s*(.+)/;
-        $pass = $1 if $l =~ m/password\s*=\s*(.+)/;
+    while(<PASS>) {
+        $user = $1 if /user\s*=\s*(.+)/;
+        $pass = $1 if /password\s*=\s*(.+)/;
 
         last if($user and $pass);
     }
@@ -206,9 +186,6 @@ MySQL::Easy - Perl extension to make your base code kinda pretty.
        # You know, print "val: $_\n" for @$arr;
        # very handy...
 
-   $id = $dbo->last_insert_id;
-       # self explainatory?
-
    $dbo->trace(1); $dbo->do("sql"); $dbo->trace(0);
        # turns the DBI trace on and off.
 
